@@ -384,6 +384,10 @@ ADD  `fixed_next_time` int(10) unsigned NOT NULL;");
 /*1.24.3 fixed bug of mysql when shceduler SMS*/
 /*1.24.3 fixed bug of call expiry*/
 /*1.24.4 fixed bug of imsi when init and doapi when value=0*/
+/*1.24.4 fixed bug of receive SMS to http */
+/*1.25 add senttime in receive SMS */
+	@$db->updatequery("ALTER TABLE `receive` ADD `senttime` DATETIME NOT NULL");
 
+/*1.25 fixed bug of cron SMS and &$ in resend.php */
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
